@@ -5,7 +5,7 @@ import json
 import logging
 import os
 import re
-from typing import TYPE_CHECKING, Dict, Optional
+from typing import TYPE_CHECKING, Dict, List, Optional
 
 from pydantic import BaseModel
 
@@ -15,7 +15,7 @@ from magnus.nodes import BaseNode
 
 if TYPE_CHECKING:
     from magnus.catalog import BaseCatalog
-    from magnus.datastore import BaseRunLogStore, StepLog
+    from magnus.datastore import BaseRunLogStore, DataCatalog, StepLog
     from magnus.experiment_tracker import BaseExperimentTracker
     from magnus.secrets import BaseSecrets
 
@@ -93,7 +93,7 @@ class BaseExecutor:
         self.run_log_store: BaseRunLogStore = None  # type: ignore
         self.previous_run_log = None
 
-        self.context_step_log: StepLog = None  # type: ignore
+        self.context_step_log: Optional[StepLog] = None
 
     @property
     def step_decorator_run_id(self):
@@ -272,12 +272,15 @@ class BaseExecutor:
         # If the key already exists, do not update it to give priority to parameters set by environment variables
         interaction.store_parameter(update=False, **parameters)
 
-        data_catalogs_get = self._sync_catalog(node, step_log, stage='get')
+        data_catalogs_get: List[DataCatalog] = []
 
         mock = step_log.mock
         logger.info(f'Trying to execute node: {node.internal_name}, attempt : {attempts}, max_attempts: {max_attempts}')
         while attempts < max_attempts:
             try:
+                if not data_catalogs_get:
+                    data_catalogs_get = self._sync_catalog(node, step_log, stage='get')
+
                 self.context_step_log = step_log
                 attempt_log = node.execute(executor=self, mock=mock,
                                            map_variable=map_variable, **kwargs)
@@ -289,6 +292,7 @@ class BaseExecutor:
                 step_log.status = defaults.SUCCESS
                 step_log.user_defined_metrics = utils.get_tracked_data()
                 self.run_log_store.set_parameters(self.run_id, utils.get_user_set_parameters(remove=True))
+                self._sync_catalog(node, step_log, stage='put', synced_catalogs=data_catalogs_get)
                 break
             except Exception as _e:  # pylint: disable=W0703
                 attempts += 1
@@ -303,7 +307,6 @@ class BaseExecutor:
                 step_log.status = defaults.FAIL
                 logger.error(f'Node {node} failed, max retries of {max_attempts} reached')
 
-        self._sync_catalog(node, step_log, stage='put', synced_catalogs=data_catalogs_get)
         self.run_log_store.add_step_log(step_log, self.run_id)
 
     def execute_node(self, node: BaseNode, map_variable: dict = None, **kwargs):
@@ -387,16 +390,16 @@ class BaseExecutor:
 
     def trigger_job(self, node: BaseNode, map_variable: dict = None, **kwargs):
         """
-        Executor specific way of triggering jobs.
+        Executor specific way of triggering jobs when magnus does both traversal and execution
 
         Args:
             node (BaseNode): The node to execute
             map_variable (str, optional): If the node if of a map state, this corresponds to the value of iterable.
                     Defaults to ''.
 
-        Raises: NotImplementedError Base class hence not implemented
+        NOTE: We do not raise an exception as this method is not required by many extensions
         """
-        raise NotImplementedError
+        pass
 
     def _get_status_and_next_node_name(self, current_node: BaseNode, dag: Graph, map_variable: dict = None):
         """
@@ -810,21 +813,6 @@ class DemoRenderer(BaseExecutor):
         if step_log.status == defaults.FAIL:
             raise Exception(f'Step {node.name} failed')
 
-    def trigger_job(self, node: BaseNode, map_variable: dict = None, **kwargs):
-        """
-        Executor specific way of triggering jobs.
-
-        This method has to be changed to do what exactly you want as part of your computational engine
-
-        If your compute is not local, use utils.get_node_execution_command(self, node, map_variable=map_variable)
-        to get the command to run a single node.
-
-        If the compute is local to the environment, calls prepare_for_node_execution and call _execute_node
-        NOTE: This method should always be implemented.
-        """
-        self.prepare_for_node_execution()
-        self.execute_node(node=node, map_variable=map_variable, **kwargs)
-
     def send_return_code(self, stage='traversal'):
         """
         Convenience function used by pipeline to send return code to the caller of the cli
